
### **Globales**

Iterar en todos los accesos directos. Accesos directos disponibles para todas las aplicaciones.

```py
    for acceso_directo, comando in app.shortcuts:
        app.debug(acceso_directo, comando)
```

Devolver una lista de tuplas con toda la información.

```py
    datos = app.shortcuts.get_all()
    app.debug(datos)
```

Verificar si un acceso directo esta asignado.

```py
    acceso_directo = 'Shift+Ctrl+Alt+T'
    app.debug(acceso_directo in app.shortcuts)
```

<br>

### **set**

Establecer un acceso directo a un comando.

```py
    sc = app.shortcuts
    acceso_directo = 'Shift+Ctrl+Alt+T'
    comando = 'MacroDialog'
    sc.set(acceso_directo, comando)
```

Establecer un acceso directo a una macro.

!!! tip inline end

    Para la asignación de una macros, aplican las mismas reglas de: [ejecutar macros](../../tools/macros/)

```py
    sc = app.shortcuts
    acceso_directo = 'Shift+Ctrl+Alt+M'
    macro = {'library': 'test', 'name': 'pruebas'}
    sc.set(acceso_directo, macro)
```

<br>

### **get_by_shortcut**

Devolver el comando asociado a un acceso directo.

```py
    sc = app.shortcuts
    acceso_directo = 'Shift+Ctrl+Alt+M'
    comando = sc.get_by_shortcut(acceso_directo)
    app.debug(comando)
```

<br>

### **get_by_command**

Devolver el acceso directo asociado a un comando. Puede haber más de uno.

```py
    sc = app.shortcuts
    comando = 'MacroDialog'
    acceso_directo = sc.get_by_command(comando)
    app.debug(acceso_directo)
```

<br>

### **remove_by_shortcut**

Eliminar por acceso directo.

```py
    sc = app.shortcuts
    acceso_directo = 'Shift+Ctrl+Alt+T'
    sc.remove_by_shortcut(acceso_directo)
```

<br>

### **remove_by_command**

Eliminar por comando.

```py
    sc = app.shortcuts
    macro = {'library': 'test', 'name': 'pruebas'}
    sc.remove_by_command(macro)
```

<br>

### **reset**

Reiniciar todas las modificaciones.

```py
    app.shortcuts.reset()
```
<br>

### **Por aplicación**

Modificar accesos directos, solo en una aplicación.

Por ejemplo Calc.

```py
    sc = app.shortcuts['calc']
```

Los métodos son los mismos que los globales.

Para las demas aplicaciones: `writer`, `draw`, `impress`, `math`.

<br>